
# Slot: equals_number_in


the slot must have range number and the value of the slot must equal one of the specified values

URI: [linkml:equals_number_in](https://w3id.org/linkml/equals_number_in)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [Integer](types/Integer.md)

## Parents

 *  is_a: [list_value_specification_constant](list_value_specification_constant.md)

## Children


## Used by

